@@ -330,7 +330,7 @@ typedef enum {
  */
 /*@{*/
 GWENHYWFAR_API 
-GWEN_GUI *GWEN_Gui_new();
+GWEN_GUI *GWEN_Gui_new(void);
 
 GWENHYWFAR_API 
 void GWEN_Gui_free(GWEN_GUI *gui);
@@ -342,7 +342,7 @@ GWENHYWFAR_API
 void GWEN_Gui_SetGui(GWEN_GUI *gui);
 
 GWENHYWFAR_API 
-GWEN_GUI *GWEN_Gui_GetGui();
+GWEN_GUI *GWEN_Gui_GetGui(void);
 
 /*@}*/
 
@@ -590,6 +590,9 @@ uint32_t GWEN_Gui_ProgressStart(uint32_t progressFlags,
 GWENHYWFAR_API 
 int GWEN_Gui_ProgressAdvance(uint32_t id, uint32_t progress);
 
+GWENHYWFAR_API 
+int GWEN_Gui_ProgressSetTotal(uint32_t id, uint64_t total);
+
 /**
  * Adds a log message to the referred process dialog.
  * <p>
@@ -865,7 +868,7 @@ GWENHYWFAR_API void GWEN_Gui_SubFlags(GWEN_GUI *gui, uint32_t fl);
 /*@}*/
 
 
-GWENHYWFAR_API const char *GWEN_Gui_GetName();
+GWENHYWFAR_API const char *GWEN_Gui_GetName(void);
 
 
 #ifdef __cplusplus
